@@ -1,8 +1,24 @@
-package Search::Elasticsearch::Client::6_0::Direct::Tasks;
-$Search::Elasticsearch::Client::6_0::Direct::Tasks::VERSION = '6.80_1'; # TRIAL
+# Licensed to Elasticsearch B.V. under one or more contributor
+# license agreements. See the NOTICE file distributed with
+# this work for additional information regarding copyright
+# ownership. Elasticsearch B.V. licenses this file to you under
+# the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#   http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
 
-$Search::Elasticsearch::Client::6_0::Direct::Tasks::VERSION = '6.801';use Moo;
-with 'Search::Elasticsearch::Client::6_0::Role::API';
+package Search::Elasticsearch::Client::7_0::Direct::Tasks;
+$Search::Elasticsearch::Client::7_0::Direct::Tasks::VERSION = '7.30';
+use Moo;
+with 'Search::Elasticsearch::Client::7_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('tasks');
 
@@ -14,11 +30,11 @@ __PACKAGE__->_install_api('tasks');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::6_0::Direct::Tasks - A client for accessing the Task Management API
+Search::Elasticsearch::Client::7_0::Direct::Tasks - A client for accessing the Task Management API
 
 =head1 VERSION
 
-version 6.80_1
+version 7.30
 
 =head1 DESCRIPTION
 
